@@ -169,6 +169,7 @@ void Bitmap::SetPlanarConfiguration(unsigned int pc)
       || ts == TransferSyntax::JPEG2000Lossless
       || ts == TransferSyntax::JPEG2000
       || ts == TransferSyntax::JPIPReferenced
+      || ts == TransferSyntax::RLELossless // FIXME internally GDCM produce per-pixel output
     )
       {
       // PS 3.6 - 2011 8.2.4 JPEG 2000 IMAGE COMPRESSION
@@ -338,7 +339,7 @@ bool Bitmap::TryRAWCodec(char *buffer, bool &lossyflag) const
     codec.SetLUT( GetLUT() );
     codec.SetPixelFormat( GetPixelFormat() );
     codec.SetNeedByteSwap( GetNeedByteSwap() );
-    codec.SetNeedOverlayCleanup( AreOverlaysInPixelData() );
+    codec.SetNeedOverlayCleanup( AreOverlaysInPixelData() || UnusedBitsPresentInPixelData() );
     DataElement out;
     //bool r = codec.Decode(PixelData, out);
     bool r = codec.DecodeBytes(bv->GetPointer(), bv->GetLength(),
@@ -426,7 +427,7 @@ bool Bitmap::TryJPEGCodec(char *buffer, bool &lossyflag) const
     codec.SetPlanarConfiguration( GetPlanarConfiguration() );
     codec.SetPhotometricInterpretation( GetPhotometricInterpretation() );
     codec.SetPixelFormat( GetPixelFormat() );
-    codec.SetNeedOverlayCleanup( AreOverlaysInPixelData() );
+    codec.SetNeedOverlayCleanup( AreOverlaysInPixelData() || UnusedBitsPresentInPixelData() );
     DataElement out;
     bool r = codec.Decode(PixelData, out);
     // PHILIPS_Gyroscan-12-MONO2-Jpeg_Lossless.dcm
@@ -502,7 +503,7 @@ bool Bitmap::TryJPEGCodec2(std::ostream &os) const
     codec.SetPlanarConfiguration( GetPlanarConfiguration() );
     codec.SetPhotometricInterpretation( GetPhotometricInterpretation() );
     codec.SetPixelFormat( GetPixelFormat() );
-    codec.SetNeedOverlayCleanup( AreOverlaysInPixelData() );
+    codec.SetNeedOverlayCleanup( AreOverlaysInPixelData() || UnusedBitsPresentInPixelData() );
     DataElement out;
     bool r = codec.Code(PixelData, out);
     // PHILIPS_Gyroscan-12-MONO2-Jpeg_Lossless.dcm
@@ -545,7 +546,7 @@ bool Bitmap::TryPVRGCodec(char *buffer, bool &lossyflag) const
     //codec.SetNumberOfDimensions( GetNumberOfDimensions() );
     codec.SetPlanarConfiguration( GetPlanarConfiguration() );
     codec.SetPhotometricInterpretation( GetPhotometricInterpretation() );
-    codec.SetNeedOverlayCleanup( AreOverlaysInPixelData() );
+    codec.SetNeedOverlayCleanup( AreOverlaysInPixelData() || UnusedBitsPresentInPixelData() );
     codec.SetDimensions( GetDimensions() );
     DataElement out;
     bool r = codec.Decode(PixelData, out);
@@ -585,7 +586,7 @@ bool Bitmap::TryKAKADUCodec(char *buffer, bool &lossyflag) const
     codec.SetNumberOfDimensions( GetNumberOfDimensions() );
     codec.SetPlanarConfiguration( GetPlanarConfiguration() );
     codec.SetPhotometricInterpretation( GetPhotometricInterpretation() );
-    codec.SetNeedOverlayCleanup( AreOverlaysInPixelData() );
+    codec.SetNeedOverlayCleanup( AreOverlaysInPixelData() || UnusedBitsPresentInPixelData() );
     codec.SetDimensions( GetDimensions() );
     DataElement out;
     bool r = codec.Decode(PixelData, out);
@@ -658,7 +659,7 @@ bool Bitmap::TryJPEGLSCodec(char *buffer, bool &lossyflag) const
     codec.SetNumberOfDimensions( GetNumberOfDimensions() );
     codec.SetPlanarConfiguration( GetPlanarConfiguration() );
     codec.SetPhotometricInterpretation( GetPhotometricInterpretation() );
-    codec.SetNeedOverlayCleanup( AreOverlaysInPixelData() );
+    codec.SetNeedOverlayCleanup( AreOverlaysInPixelData() || UnusedBitsPresentInPixelData() );
     codec.SetDimensions( GetDimensions() );
     DataElement out;
     bool r = codec.Decode(PixelData, out);
@@ -775,7 +776,7 @@ bool Bitmap::TryJPEG2000Codec(char *buffer, bool &lossyflag) const
     codec.SetNumberOfDimensions( GetNumberOfDimensions() );
     codec.SetPlanarConfiguration( GetPlanarConfiguration() );
     codec.SetPhotometricInterpretation( GetPhotometricInterpretation() );
-    codec.SetNeedOverlayCleanup( AreOverlaysInPixelData() );
+    codec.SetNeedOverlayCleanup( AreOverlaysInPixelData() || UnusedBitsPresentInPixelData() );
     codec.SetDimensions( GetDimensions() );
     DataElement out;
     bool r = codec.Decode(PixelData, out);
@@ -842,7 +843,7 @@ bool Bitmap::TryJPEG2000Codec2(std::ostream &os) const
     codec.SetNumberOfDimensions( GetNumberOfDimensions() );
     codec.SetPlanarConfiguration( GetPlanarConfiguration() );
     codec.SetPhotometricInterpretation( GetPhotometricInterpretation() );
-    codec.SetNeedOverlayCleanup( AreOverlaysInPixelData() );
+    codec.SetNeedOverlayCleanup( AreOverlaysInPixelData() || UnusedBitsPresentInPixelData() );
     DataElement out;
     bool r = codec.Code(PixelData, out);
     assert( r );
@@ -873,7 +874,7 @@ bool Bitmap::TryRLECodec(char *buffer, bool &lossyflag ) const
     codec.SetPhotometricInterpretation( GetPhotometricInterpretation() );
     codec.SetPixelFormat( GetPixelFormat() );
     codec.SetLUT( GetLUT() );
-    codec.SetNeedOverlayCleanup( AreOverlaysInPixelData() );
+    codec.SetNeedOverlayCleanup( AreOverlaysInPixelData() || UnusedBitsPresentInPixelData() );
     codec.SetBufferLength( len );
     DataElement out;
     bool r = codec.Decode(PixelData, out);
