@@ -248,7 +248,7 @@ bool JPEGLSCodec::Decode(DataElement const &in, DataElement &out)
         {
         return false;
         }
-      os.write( (char*)&rgbyteOut[0], rgbyteOut.size() );
+      os.write( (const char*)&rgbyteOut[0], rgbyteOut.size() );
 
       if(!r) return false;
       assert( r == true );
@@ -374,7 +374,7 @@ bool JPEGLSCodec::Code(DataElement const &in, DataElement &out)
     const char *inputdata = input + dim * image_len;
 
     std::vector<BYTE> rgbyteCompressed;
-    rgbyteCompressed.resize(image_width * image_height * 4);
+    rgbyteCompressed.resize(image_width * image_height * 4 * 2); // overallocate in case of weird case
 
     size_t cbyteCompressed;
     const bool b = this->CodeFrameIntoBuffer((char*)&rgbyteCompressed[0], rgbyteCompressed.size(), cbyteCompressed, inputdata, inputlength );
